@@ -9,7 +9,9 @@ class FiberData(InternetData):
         self.previous_contract_fiber_speed = args.get("previous_contract_fiber_speed", "")
         self.activation_notes = args.get("activation_notes", "")
         self.all_grouped_SIMS_recieved = args.get("all_grouped_SIMS_recieved")
+        self.has_grouped_mobile_with_previous_owner = args.get("has_grouped_mobile_with_previous_owner")
         for key in ["previous_contract_pon", "previous_contract_fiber_speed",
-                    "activation_notes", "all_grouped_SIMS_recieved"]:
+                    "activation_notes", "all_grouped_SIMS_recieved",
+                    "has_grouped_mobile_with_previous_owner"]:
             args.pop(key, None)
         super().__init__(**args)
