@@ -23,6 +23,8 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             'name',
             'vat_number',
             'phone',
+            'has_active_contracts',
+            'language'
         ])
         self.service_data = Mock(spec=[
             'order_id',
@@ -54,6 +56,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             'type',
             'product',
             'previous_internal_provider',
+            'technology'
         ])
 
         self.adsl_otrs_process_id = "ADSLProcessID"
@@ -157,6 +160,45 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["telefonContacte"], "666666666")
 
+    def test_has_active_contracts_field(self):
+        self.customer_data.has_active_contracts = True
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["teContractesActius"], "1")
+
+    def test_has_active_contracts_false_field(self):
+        self.customer_data.has_active_contracts = False
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["teContractesActius"], "0")
+
+    def test_language_field(self):
+        self.customer_data.language = "ca_ES"
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["idioma"], "ca_ES")
+
     def test_contact_email_field(self):
         self.service_data.email = "test@email.org"
 
@@ -502,3 +544,16 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertNotIn("proveidorPrevi", dynamic_fields_dct.keys())
+
+    def test_tecnhology(self):
+        self.service_data.technology = "ADSL"
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["TecDelServei"], "ADSL")
\ No newline at end of file
